import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var CELL_TYPE = {
  header: 'th',
  data: 'td'
};
var CELL_PADDING = {
  xs: 'xs',
  s: 's',
  m: 'm',
  l: 'l',
  xl: 'l'
};

var AtomTable = function AtomTable(_ref) {
  var _cx, _cx2;

  var head = _ref.head,
      body = _ref.body,
      foot = _ref.foot,
      fullWidth = _ref.fullWidth,
      cellPadding = _ref.cellPadding,
      borderBottom = _ref.borderBottom;
  var hasHead = Boolean(head == null ? void 0 : head.length);
  var hasFoot = Boolean(foot == null ? void 0 : foot.length);
  var baseClass = 'react-AtomTable';
  var tableClass = cx("" + baseClass, (_cx = {}, _cx[baseClass + "--fullWidth"] = Boolean(fullWidth), _cx));
  var headerClass = cx(baseClass + "-cell", baseClass + "-headerCell", (_cx2 = {}, _cx2[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx2));
  return React.createElement("table", {
    className: tableClass
  }, hasHead && React.createElement("thead", null, React.createElement("tr", null, head.map(function (element, index) {
    return React.createElement("th", {
      key: index,
      className: headerClass
    }, element);
  }))), React.createElement("tbody", null, body.map(function (row, index) {
    return React.createElement("tr", {
      key: index
    }, row.map(function (cell, index) {
      var _cx3;

      var _cell$type = cell.type,
          Element = _cell$type === void 0 ? CELL_TYPE.data : _cell$type,
          _cell$content = cell.content,
          content = _cell$content === void 0 ? '' : _cell$content,
          isNowrap = cell.isNowrap,
          _cell$colspan = cell.colspan,
          colspan = _cell$colspan === void 0 ? 1 : _cell$colspan;
      var cellClassName = cx(baseClass + "-cell", (_cx3 = {}, _cx3[baseClass + "-cell--noWrap"] = isNowrap, _cx3[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx3[baseClass + "-cell--borderBottom"] = Boolean(borderBottom), _cx3));
      return React.createElement(Element, {
        key: index,
        className: cellClassName,
        colspan: colspan
      }, content);
    }));
  })), hasFoot && React.createElement("tfoot", null, React.createElement("tr", null, foot.map(function (element, index) {
    return React.createElement("td", {
      key: index,
      className: baseClass + "-cell"
    }, element);
  }))));
};

AtomTable.displayName = 'AtomTable';
export { CELL_TYPE as atomTableCellTypes, CELL_PADDING as atomTableCellPadding };
export default AtomTable;